Crate agglayer_interop_types

Crate agglayer_interop_types 

Re-exports

pub use agglayer_bincode as bincode;
pub use agglayer_primitives as primitives;

Modules

aggchain_proof

Structs

Address
A wrapper over alloy_primitives::Address that allows us to add custom methods and trait implementations.
BridgeExit
Represents a token bridge exit from the network.
ClaimFromMainnet
ClaimFromRollup
Digest
GlobalIndex
The GlobalIndex uniquely references one leaf within one Global Exit Tree.
GlobalIndexWithLeafHash
Refers to one claim as per its global index and the hash of the underlying bridge exit.
ImportedBridgeExit
Represents a token bridge exit originating on another network but claimed on the current network.
ImportedBridgeExitCommitmentValues
The values which compose the commitment on the imported bridge exits.
L1InfoRoot
L1InfoTreeLeaf
L1InfoTreeLeafInner
LocalBalanceRoot
LocalExitRoot
LocalNullifierRoot
MerkleProof
NetworkId
A network ID.
PessimisticRoot
Signature
A wrapper over AlloySignature with custom serialization.
TokenInfo
Encapsulates the information to uniquely identify a token on the origin network.

Enums

Claim
Error
LeafType

Type Aliases

B256
32-byte fixed byte-array type.
CertificateId
EpochNumber
U256
256-bit unsigned integer type, consisting of 4, 64-bit limbs.
U512
512-bit unsigned integer type, consisting of 8, 64-bit limbs.