ImportedBridgeExit

Struct ImportedBridgeExit 

pub struct ImportedBridgeExit {
    pub bridge_exit: BridgeExit,
    pub claim_data: Claim,
    pub global_index: GlobalIndex,
}
Represents a token bridge exit originating on another network but claimed on the current network.

Fields

bridge_exit: BridgeExit

The bridge exit initiated on another network, called the “sending” network. Need to verify that the destination network matches the current network, and that the bridge exit is included in an imported LER

claim_data: Claim

The claim data

global_index: GlobalIndex

The global index of the imported bridge exit.

Implementations

Source

impl ImportedBridgeExit

pub fn verify_path(&self, l1root: Digest) -> Result<(), Error>

Verifies that the provided inclusion path is valid and consistent with the provided LER

Source

impl ImportedBridgeExit

pub fn new( bridge_exit: BridgeExit, claim_data: Claim, global_index: GlobalIndex, ) -> ImportedBridgeExit

Creates a new ImportedBridgeExit.

pub fn l1_info_root(&self) -> Digest

Returns the considered L1 Info Root against which the claim is done.

pub fn l1_leaf_index(&self) -> u32

Returns the considered L1 Info Tree leaf index against which the claim is done.

pub fn hash(&self) -> Digest

Hash the entire data structure.

Source

impl ImportedBridgeExit

pub fn valid_claim(&self) -> bool

pub fn to_indexed_exit_hash(&self) -> GlobalIndexWithLeafHash

Returns the global index and the underlying bridge exit leaf hash.