pub struct ImportedBridgeExitCommitmentValues {
pub claims: Vec<GlobalIndexWithLeafHash>,
}Expand description
The values which compose the commitment on the imported bridge exits.
Fields
claims: Vec<GlobalIndexWithLeafHash>Implementations
Sourceimpl ImportedBridgeExitCommitmentValues
impl ImportedBridgeExitCommitmentValues
Sourcepub fn commitment(&self, version: ImportedBridgeExitCommitmentVersion) -> Digest
pub fn commitment(&self, version: ImportedBridgeExitCommitmentVersion) -> Digest
Returns the expected signed commitment for the provided version.