Re-exports
pub use agglayer_bincode as bincode;pub use agglayer_primitives as primitives;
Modules
Structs
- Address
- A wrapper over alloy_primitives::Address that allows us to add custom methods and trait implementations.
- Bridge
Exit - Represents a token bridge exit from the network.
- Claim
From Mainnet - Claim
From Rollup - Digest
- Global
Index - The
GlobalIndexuniquely references one leaf within one Global Exit Tree. - Global
Index With Leaf Hash - Refers to one claim as per its global index and the hash of the underlying bridge exit.
- Imported
Bridge Exit - Represents a token bridge exit originating on another network but claimed on the current network.
- Imported
Bridge Exit Commitment Values - The values which compose the commitment on the imported bridge exits.
- L1Info
Root - L1Info
Tree Leaf - L1Info
Tree Leaf Inner - Local
Balance Root - Local
Exit Root - Local
Nullifier Root - Merkle
Proof - Network
Id - A network ID.
- Pessimistic
Root - Signature
- A wrapper over AlloySignature with custom serialization.
- Token
Info - Encapsulates the information to uniquely identify a token on the origin network.
Enums
Type Aliases
- B256
- 32-byte fixed byte-array type.
- Certificate
Id - Epoch
Number - U256
- 256-bit unsigned integer type, consisting of 4, 64-bit limbs.
- U512
- 512-bit unsigned integer type, consisting of 8, 64-bit limbs.